@@ -1,10 +1,10 @@
 !
-!  This file is part of MUMPS 5.1.2, released
-!  on Mon Oct  2 07:37:01 UTC 2017
+!  This file is part of MUMPS 5.2.1, released
+!  on Fri Jun 14 14:46:05 UTC 2019
 !
 !
-!  Copyright 1991-2017 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
-!  University of Bordeaux.
+!  Copyright 1991-2019 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+!  Mumps Technologies, University of Bordeaux.
 !
 !  This version of MUMPS is provided to you free of charge. It is
 !  released under the CeCILL-C license:
@@ -83,6 +83,9 @@
       PARAMETER (MPI_INTEGER8=33)
       PARAMETER (MPI_REAL8=34)
 
+      INTEGER MPI_IN_PLACE
+      COMMON/mpif_libseq/MPI_IN_PLACE
+
       PARAMETER (MPI_BSEND_OVERHEAD=0)
       DOUBLE PRECISION MPI_WTIME
       EXTERNAL MPI_WTIME
