@@ -1,4 +1,4 @@
-/* Copyright 2004,2007-2015 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007-2016,2018,2019 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -53,7 +53,7 @@
 /**                # Version 5.1  : from : 09 nov 2008     **/
 /**                                 to   : 23 nov 2010     **/
 /**                # Version 6.0  : from : 03 mar 2011     **/
-/**                                 to     01 mar 2015     **/
+/**                                 to     30 oct 2019     **/
 /**                                                        **/
 /************************************************************/
 
@@ -70,8 +70,25 @@
 #define __USE_XOPEN2K                             /* For POSIX pthread_barrier_t */
 #endif /* __USE_XOPEN2K */
 
-#include            <ctype.h>
+#ifdef COMMON_WINDOWS
+#include            <io.h>                        /* For _pipe ()              */
 #include            <fcntl.h>                     /* Fow Windows _pipe () call */
+#include            <stddef.h>                    /* For intptr_t              */
+#include            <windows.h>
+#define HAVE_STDINT_H
+#define HAVE_UINT_T
+#define HAVE_NOT_SYS_WAIT_H
+#ifdef _MSC_VER
+#define HAVE_NOT_STRINGS_H
+#endif /* _MSC_VER */
+#ifdef _WIN32
+#define strncasecmp                 strnicmp
+#define strcasecmp                  stricmp
+#endif /* _WIN32 */
+#define pipe(fd)                    _pipe (fd, 32768, O_BINARY)
+#endif /* COMMON_WINDOWS */
+
+#include            <ctype.h>
 #include            <math.h>
 #include            <memory.h>
 #include            <stdio.h>
@@ -79,12 +96,15 @@
 #include            <stdlib.h>
 #if (((defined __STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)) || (defined HAVE_STDINT_H))
 #include            <stdint.h>
+#include            <inttypes.h>
 #endif /* (((defined __STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)) || (defined HAVE_STDINT_H)) */
 #ifdef HAVE_MALLOC_H
 #include            <malloc.h>                    /* Deprecated, but required on some old systems */
 #endif /* HAVE_MALLOC_H */
 #include            <string.h>
+#ifndef HAVE_NOT_STRINGS_H
 #include            <strings.h>
+#endif /* HAVE_NOT_STRINGS_H */
 #include            <time.h>                      /* For the effective calls to clock () */
 #include            <limits.h>
 #include            <float.h>
@@ -95,23 +115,23 @@
 #if ((defined COMMON_TIMING_OLD) || (defined HAVE_SYS_RESOURCE_H))
 #include            <sys/resource.h>
 #endif /* ((defined COMMON_TIMING_OLD) || (defined HAVE_SYS_RESOURCE_H)) */
-#if ((defined COMMON_WINDOWS) || (defined HAVE_WINDOWS_H))
-#include            <io.h>                        /* For _pipe () */
-#include            <stddef.h>                    /* For intptr_t */
-#include            <windows.h>
-#endif /* ((defined COMMON_WINDOWS) || (defined HAVE_WINDOWS_H)) */
 #if ((! defined COMMON_WINDOWS) && (! defined HAVE_NOT_UNISTD_H))
 #include            <unistd.h>
 #endif /* ((! defined COMMON_WINDOWS) && (! defined HAVE_NOT_UNISTD_H)) */
 
-#ifdef SCOTCH_PTSCOTCH
+#ifdef COMMON_MPI
 #include            <mpi.h>
-#endif /* SCOTCH_PTSCOTCH */
+#endif /* COMMON_MPI */
 
-#if ((defined COMMON_PTHREAD) || (defined SCOTCH_PTHREAD))
+#ifdef COMMON_PTHREAD
 #include            <pthread.h>
-#endif /* ((defined COMMON_PTHREAD) || (defined SCOTCH_PTHREAD)) */
+#else /* COMMON_PTHREAD */
+#ifndef HAVE_NOT_SYS_WAIT_H
+#include            <sys/wait.h>                  /* For waitpid () */
+#endif /* HAVE_NOT_SYS_WAIT_H */
+#endif /* COMMON_PTHREAD */
 
+#include <R_ext/Error.h>
 /*
 **  Working definitions.
 */
@@ -119,23 +139,29 @@
 #ifdef COMMON_MEMORY_TRACE
 #define memAlloc(size)              memAllocRecord ((size) | 8)
 #define memRealloc(ptr,size)        memReallocRecord ((ptr), ((size) | 8))
-/*#define memFree(ptr)                (memFreeRecord ((void *) (ptr)), 0)*/
-#define memFree(ptr)                (memFreeRecord ((void *) (ptr)))
+#define memFree(ptr)                memFreeRecord ((void *) (ptr))
 #else /* COMMON_MEMORY_TRACE */
 #define memAlloc(size)              malloc ((size) | 8) /* For platforms which return NULL for malloc(0) */
 #define memRealloc(ptr,size)        realloc ((ptr),((size) | 8))
-/*#define memFree(ptr)                (free ((char *) (ptr)), 0)*/
-#define memFree(ptr)                (free ((char *) (ptr)))
+#define memFree(ptr)                free ((char *) (ptr))
 #endif /* COMMON_MEMORY_TRACE */
 
 #define memSet(ptr,val,siz)         memset ((void *) (ptr), (val), (siz))
 #define memCpy(dst,src,siz)         memcpy ((void *) (dst), (void *) (src), (siz))
 #define memMov(dst,src,siz)         memmove ((void *) (dst), (void *) (src), (siz))
 
+#ifndef MIN
 #define MIN(x,y)                    (((x) < (y)) ? (x) : (y))
+#endif /* MIN */
+#ifndef MAX
 #define MAX(x,y)                    (((x) < (y)) ? (y) : (x))
+#endif /* MAX */
+#ifndef ABS
 #define ABS(x)                      MAX ((x), -(x))
+#endif /* ABS */
+#ifndef SIGN
 #define SIGN(x)                     (((x) < 0) ? -1 : 1)
+#endif /* SIGN */
 
 /*
 **  Handling of generic types.
@@ -152,7 +178,13 @@
 #define INT                         int32_t
 #define UINT                        UINT32
 #define COMM_INT                    MPI_INTEGER4
+#ifdef PRId32
+#define INTSTRING                   "%" PRId32
+#define UINTSTRING                  "%" PRIu32
+#else /* PRId32 */
 #define INTSTRING                   "%d"
+#define UINTSTRING                  "%u"
+#endif /* PRId32 */
 #else /* INTSIZE32 */
 #ifdef INTSIZE64
 #define INT                         int64_t
@@ -162,18 +194,26 @@
 #define UINT                        u_int64_t
 #endif /* (((defined __STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)) || (defined HAVE_UINT_T)) */
 #define COMM_INT                    MPI_LONG_LONG
+#ifdef PRId64
+#define INTSTRING                   "%" PRId64
+#define UINTSTRING                  "%" PRIu64
+#else /* PRId64 */
 #define INTSTRING                   "%lld"
+#define UINTSTRING                  "%llu"
+#endif /* PRId64 */
 #else /* INTSIZE64 */
 #ifdef LONG                                       /* Better not use it */
 #define INT                         long          /* Long integer type */
 #define UINT                        unsigned long
 #define COMM_INT                    MPI_LONG
 #define INTSTRING                   "%ld"
+#define UINTSTRING                  "%lu"
 #else /* LONG */
 #define INT                         int           /* Default integer type */
 #define UINT                        unsigned int
 #define COMM_INT                    MPI_INT       /* Generic MPI integer type */
 #define INTSTRING                   "%d"
+#define UINTSTRING                  "%u"
 #endif /* LONG      */
 #endif /* INTSIZE64 */
 #endif /* INTSIZE32 */
@@ -237,14 +277,6 @@ typedef struct Clock_ {
   double                    time[2];              /*+ The start and accumulated times +*/
 } Clock;
 
-/*
-**  Handling of Windows constructs.
-*/
-
-#if defined COMMON_WINDOWS
-#define pipe(fd)                    _pipe (fd, 32768, O_BINARY)
-#endif /* COMMON_WINDOWS */
-
 /*
 **  Handling of threads.
 */
@@ -301,54 +333,44 @@ typedef void (* ThreadScanFunc)   (void * const, void * const, void * const, con
 /** The thread group header block. **/
 
 typedef struct ThreadGroupHeader_ {
-#if ((defined COMMON_PTHREAD) || (defined SCOTCH_PTHREAD))
   int                       flagval;              /*+ Thread block flags       +*/
+#ifdef COMMON_PTHREAD
   size_t                    datasiz;              /*+ Size of data array cell  +*/
   int                       thrdnbr;              /*+ Number of threads        +*/
   ThreadLaunchStartFunc     stafptr;              /*+ Pointer to start routine +*/
   ThreadLaunchJoinFunc      joifptr;              /*+ Pointer to join routine  +*/
   ThreadBarrier             barrdat;              /*+ Barrier data structure   +*/
-#endif /* ((defined COMMON_PTHREAD) || (defined SCOTCH_PTHREAD)) */
+#endif /* COMMON_PTHREAD */
 } ThreadGroupHeader;
 
 /** The thread header block. **/
 
 typedef struct ThreadHeader_ {
   void *                    grouptr;              /*+ Pointer to thread group +*/
-#if ((defined COMMON_PTHREAD) || (defined SCOTCH_PTHREAD))
+#ifdef COMMON_PTHREAD
   pthread_t                 thidval;              /*+ Thread ID               +*/
   int                       thrdnum;              /*+ Thread instance number  +*/
-#endif /* ((defined COMMON_PTHREAD) || (defined SCOTCH_PTHREAD)) */
+#endif /* COMMON_PTHREAD */
 } ThreadHeader;
 
-/** The number of threads **/
-
-#ifdef SCOTCH_PTHREAD
-
-#ifndef SCOTCH_PTHREAD_NUMBER
-#define SCOTCH_PTHREAD_NUMBER       1
-#endif /* SCOTCH_PTHREAD_NUMBER */
-
-#else /* SCOTCH_PTHREAD */
-
-#ifdef SCOTCH_PTHREAD_NUMBER
-#undef SCOTCH_PTHREAD_NUMBER
-#endif /* SCOTCH_PTHREAD_NUMBER */
-#define SCOTCH_PTHREAD_NUMBER       1
-
-#endif /* SCOTCH_PTHREAD */
-
 /*
 **  Handling of files.
 */
 
+/** The file flags **/
+
+#define FILEMODE                    0x0001
+#define FILEMODER                   0x0000
+#define FILEMODEW                   0x0001
+#define FILEFREENAME                0x0002
+
 /** The file structure. **/
 
 typedef struct File_ {
-  char *                    modeptr;              /*+ Opening mode  +*/
-  char *                    nameptr;              /*+ File name     +*/
-  FILE *                    fileptr;              /*+ File pointer  +*/
-  char *                    dataptr;              /*+ Array to free +*/
+  int                       flagval;              /*+ File mode            +*/
+  char *                    nameptr;              /*+ File name            +*/
+  FILE *                    fileptr;              /*+ File pointer         +*/
+  struct FileCompress_ *    compptr;              /*+ (De)compression data +*/
 } File;
 
 /*
@@ -372,11 +394,12 @@ void                        fileBlockInit       (File * const, const int);
 int                         fileBlockOpen       (File * const, const int);
 int                         fileBlockOpenDist   (File * const, const int, const int, const int, const int);
 void                        fileBlockClose      (File * const, const int);
-FILE *                      fileCompress        (FILE * const, const int);
+int                         fileCompress        (File * const, const int);
+void                        fileCompressExit    (File * const);
 int                         fileCompressType    (const char * const);
-FILE *                      fileUncompress      (FILE * const, const int);
-int                         fileUncompressType  (const char * const);
-int                         fileNameDistExpand  (char ** const, const int, const int, const int);
+int                         fileDecompress      (File * const, const int);
+int                         fileDecompressType  (const char * const);
+char *                      fileNameDistExpand  (char * const, const int, const int);
 
 void                        errorProg           (const char * const);
 void                        errorPrint          (const char * const, ...);
@@ -387,11 +410,13 @@ int                         intSave             (FILE * const, const INT);
 void                        intAscn             (INT * const, const INT, const INT);
 void                        intPerm             (INT * const, const INT);
 void                        intRandInit         (void);
+int                         intRandLoad         (FILE * const);
 void                        intRandProc         (int);
 void                        intRandReset        (void);
+int                         intRandSave         (FILE * const);
 void                        intRandSeed         (INT);
 #ifndef COMMON_RANDOM_SYSTEM
-INT                         intRandVal          (INT);
+UINT                        intRandVal          (UINT);
 #endif /* COMMON_RANDOM_SYSTEM */
 void                        intSort1asc1        (void * const, const INT);
 void                        intSort2asc1        (void * const, const INT);
@@ -430,9 +455,9 @@ void                        threadScan          (void * const, void * const, Thr
 
 #ifdef COMMON_RANDOM_SYSTEM
 #ifdef COMMON_RANDOM_RAND
-#define intRandVal(ival)            ((INT) (((UINT) rand ()) % ((UINT) (ival))))
+#define intRandVal(ival)            ((UINT) (((UINT) rand ()) % ((UINT) (ival))))
 #else /* COMMON_RANDOM_RAND */
-#define intRandVal(ival)            ((INT) (((UINT) random ()) % ((UINT) (ival))))
+#define intRandVal(ival)            ((UINT) (((UINT) random ()) % ((UINT) (ival))))
 #endif /* COMMON_RANDOM_RAND */
 #endif /* COMMON_RANDOM_SYSTEM */
 
@@ -455,3 +480,6 @@ void nu pl
 
 #define STRINGIFY2(n)               #n
 #define STRINGIFY(n)                STRINGIFY2(n)
+
+/* make inoperant exit(n) for R */
+#define exit(x) 
