@@ -1,4 +1,4 @@
-/* Copyright 2004,2007-2009,2011,2014 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007-2009,2011,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -66,7 +66,7 @@
 /**                # Version 5.1  : from : 22 nov 2007     **/
 /**                                 to     04 feb 2009     **/
 /**                # Version 6.0  : from : 03 mar 2011     **/
-/**                                 to     29 aug 2014     **/
+/**                                 to     21 jun 2019     **/
 /**                                                        **/
 /**   NOTES      : # This code is a complete rewrite of    **/
 /**                  the original code of kgraphMapRb(),   **/
@@ -199,7 +199,7 @@ KgraphMapRbMapPoolData * restrict const poolptr)
     if ((mappptr->flagval & MAPPINGFREEDOMN) != 0) /* If mapping domain array was privately owned, free it        */
       memFree (mappptr->domntab);
     mappptr->flagval |= MAPPINGFREEDOMN;          /* Keep current domain array as private mapping domain array */
-    mappptr->domntab  = poolptr->domntab[1];      
+    mappptr->domntab  = poolptr->domntab[1];
   }
 
   memFree (poolptr->jobtab);
@@ -396,9 +396,6 @@ KgraphMapRbMapJob * const       jobptr)           /* Job to be added */
       jobptr->prioval = 0;
       jobptr->priolvl = 0;
       return;
-#else
-    default :
-      return;
 #endif /* SCOTCH_DEBUG_KGRAPH2 */
   }
 
@@ -450,9 +447,6 @@ const GraphPart                 partval)
       jobnewptr->prioval = 0;
       jobnewptr->priolvl = 0;
       return;
-#else
-    default :
-      return;
 #endif /* SCOTCH_DEBUG_KGRAPH2 */
   }
 
@@ -619,9 +613,6 @@ KgraphMapRbMapJob * const       jobnewptr1)
         jobnewptr->prioval = 0;
         jobnewptr->priolvl = 0;
         return;
-#else
-      default :
-        return;
 #endif /* SCOTCH_DEBUG_KGRAPH2 */
     }
 
@@ -703,15 +694,6 @@ kgraphMapRbMapPoolRemv (
 KgraphMapRbMapPoolData * const  poolptr,
 const KgraphMapRbMapJob * const joboldptr)        /* Job to be removed */
 {
-/*  KgraphMapRbMapJob * restrict  jobtab;*/
-/*  const Anum * restrict         mapparttax;       *//* Based pointer to mapping part array */
-/*  const Gnum * restrict         jobvnumtax;*/
-/*  const Gnum * restrict         jobverttax;*/
-/*  const Gnum * restrict         jobvendtax;*/
-/*  const Gnum * restrict         topverttax;*/
-/*  const Gnum * restrict         topvendtax;*/
-/*  const Gnum * restrict         topedgetax;*/
-
   if (poolptr->polival >= KGRAPHMAPRBPOLINEIGHBOR) { /* If neighbors have to be modified */
     Gnum                jobvertnnd;
     Gnum                jobvertnum;
@@ -979,9 +961,14 @@ KgraphMapRbVflo * restrict const        vflotab)  /*+ Array of fixed vertex load
 
       if ((partval = 1, actgrafdat.compsize0 == 0) || /* If no bipartition found */
           (partval = 0, actgrafdat.compsize0 == actgrafdat.s.vertnbr)) {
-        if (((pooldat.flagval & KGRAPHMAPRBMAPARCHVAR) != 0) || /* If architecture is variable-sized     */
-            (archDomSize (mappptr->archptr, &domnsubtab[partval]) <= 1)) { /* Or if domain is terminal   */
-          pooldat.domntab[0][jobsubnum[0]] = joborgdat.domnorg; /* Update domain in next pool            */
+        if ((pooldat.flagval & KGRAPHMAPRBMAPARCHVAR) != 0) { /* If architecture is variable-sized       */
+          pooldat.domntab[0][jobsubnum[0]] = joborgdat.domnorg; /* Propagate domain in next pool         */
+          kgraphMapRbMapPoolRemv (&pooldat, &joborgdat); /* Remove job from pool as long as graph exists */
+          bgraphExit (&actgrafdat);               /* Free bipartitioning data as well as current graph   */
+          continue;                               /* Process next job in current pool                    */
+        }
+        if (archDomSize (mappptr->archptr, &domnsubtab[partval]) <= 1) { /* If domain is terminal        */
+          pooldat.domntab[0][jobsubnum[0]] = domnsubtab[partval]; /* Refine domain in next pool          */
           kgraphMapRbMapPoolRemv (&pooldat, &joborgdat); /* Remove job from pool as long as graph exists */
           bgraphExit (&actgrafdat);               /* Free bipartitioning data as well as current graph   */
           continue;                               /* Process next job in current pool                    */
