@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-**
+** 
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-**
+** 
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-**
+** 
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -40,13 +40,13 @@
 /**                libSCOTCH library.                      **/
 /**                                                        **/
 /**   DATES      : # Version 3.4  : from : 10 oct 1999     **/
-/**                                 to   : 01 nov 2001     **/
+/**                                 to     01 nov 2001     **/
 /**                # Version 4.0  : from : 18 dec 2001     **/
-/**                                 to   : 19 jan 2004     **/
+/**                                 to     19 jan 2004     **/
 /**                # Version 5.1  : from : 17 nov 2010     **/
-/**                                 to   : 17 nov 2010     **/
+/**                                 to     17 nov 2010     **/
 /**                # Version 6.0  : from : 25 apr 2018     **/
-/**                                 to   : 25 apr 2018     **/
+/**                                 to     25 apr 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -78,7 +78,7 @@
 +*/
 
 SCOTCH_Geom *
-SCOTCH_geomAlloc ()
+SCOTCH_geomAlloc (void)
 {
   return ((SCOTCH_Geom *) memAlloc (sizeof (SCOTCH_Geom)));
 }
